@@ -10,10 +10,10 @@ class GCodeListDecorator(SceneNodeDecorator):
     def getGCodeList(self) -> List[str]:
         return self._gcode_list
 
-    def setGCodeList(self, list: List[str]):
+    def setGCodeList(self, list: List[str]) -> None:
         self._gcode_list = list
 
     def __deepcopy__(self, memo) -> "GCodeListDecorator":
         copied_decorator = GCodeListDecorator()
         copied_decorator.setGCodeList(self.getGCodeList())
-        return copied_decorator
\ No newline at end of file
+        return copied_decorator
